<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package magazine
 */

if ( ! function_exists( 'magazine_posted_on' ) ) :
	/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
	function magazine_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = ' %2$s';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( 'c' ) ),
			esc_html( get_the_modified_date() )
		);

			$posted_on = $time_string;

			$byline = sprintf(
				esc_html_x( 'by %s', 'post author', 'livemagazine' ),
				'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
			);

			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'livemagazine' ) );
			/* if ( $categories_list && magazine_categorized_blog() ) {
			printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'livemagazine' ) . '</span>', $categories_list ); // WPCS: XSS OK.
			} */

			echo '<div class="byline"> ' . $byline . '</div>';
			echo '<div class="meta">';
			echo '<span class="date"><i class="fa fa-calendar"></i>' . $posted_on . '</span>';
			echo '<span class="category"><i class="fa fa-folder-open-o"></i> ' . $categories_list . '</span>';
			echo '<a class="count bubble" href="' . get_permalink() . '#comments">' . number_format_i18n( get_comments_number() ) . '</a>';
			echo '</div>';

	}
endif;

if ( ! function_exists( 'tmpl_magazine_entry_footer' ) ) :
	/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
	function tmpl_magazine_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			/* $categories_list = get_the_category_list( esc_html__( ', ', 'livemagazine' ) );
			if ( $categories_list && magazine_categorized_blog() ) {
			printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'livemagazine' ) . '</span>', $categories_list ); // WPCS: XSS OK.
			} */

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html__( ', ', 'livemagazine' ) );
			/* if ( $tags_list ) {
			printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'livemagazine' ) . '</span>', $tags_list ); // WPCS: XSS OK.
			} */

			if ( $tags_list ) {
				echo '<div class="post-meta"><b class="title">' . __( 'Tags','livemagazine' ) . ':</b> ' . $tags_list . '</div>';
			}
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link( esc_html__( 'Leave a comment', 'livemagazine' ), esc_html__( '1 Comment', 'livemagazine' ), esc_html__( '% Comments', 'livemagazine' ) );
			echo '</span>';
		}

		edit_post_link(
			sprintf(
				/* translators: %s: Name of current post */
				esc_html__( 'Edit %s', 'livemagazine' ),
				the_title( '<span class="screen-reader-text">"', '"</span>', false )
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function magazine_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'magazine_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'magazine_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so magazine_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so magazine_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in magazine_categorized_blog.
 */
function magazine_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'magazine_categories' );
}
add_action( 'edit_category', 'magazine_category_transient_flusher' );
add_action( 'save_post',     'magazine_category_transient_flusher' );
