<?php
/**
 * Widget API: Tmpl_Widget_Banner_Slider class
 *
 * @package WordPress
 * @subpackage Widgets
 * @since 4.4.0
 */

/**
 * Core class used to implement a Slider widget.
 *
 * @since 2.8.0
 *
 * @see WP_Widget
 */
if ( ! class_exists( 'Tmpl_Widget_Banner_Slider' ) ) {
	class Tmpl_Widget_Banner_Slider extends WP_Widget {

		/**
		 * Sets up a new Slider widget instance.
		 *
		 * @since 2.8.0
		 * @access public
		 */

		function __construct() {
			parent::__construct(
				'tmpl_banner_slider', // Base ID
				__( 'T &rarr; Homepage Banner','livemagazine' ), // Name
				array(
					'description' => apply_filters( 'tmpl_banner_widget_description',__( 'Display images from a collection of static images. The widget works best in the Homepage Banner area.','livemagazine' ) ),
				)
			);
		}

		/**
		 * Outputs the content for the current Slider widget instance.
		 *
		 * @since 2.8.0
		 * @access public
		 *
		 */
		function widget( $slider_args, $instance ) {
			$slider_args['before_widget'];

			/* dynamic id for slider */
			$slider_id = 'slider_' . rand( 1,9999 );

			$title     = strip_tags( $instance['title'] );
			$sdesc     = ( isset( $instance['sdesc'] ) ) ? strip_tags( $instance['sdesc'] ) : '';

			/* slider image ,title and link */
			$slider_image = ($instance['slider_image']);
			$slider_title = ($instance['slider_title']);
			$slider_title_link = ($instance['slider_title_link']);
			$animation         = empty( $instance['animation'] )? 'basic' : strip_tags( $instance['animation'] );
			$animation_speed   = empty( $instance['animation_speed'] )? '20' : strip_tags( $instance['animation_speed'] );

			$post_category = empty( $instance['post_category'] ) ? '1' : apply_filters( 'widget_post_category', $instance['post_category'] );
			$content_len = empty( $instance['content_len'] ) ? '60' : $instance['content_len'];

			$custom_banner_temp = empty( $instance['custom_banner_temp'] ) ? '' : $instance['custom_banner_temp'];
			?>
				<div class="item">
					<div id="P_<?php echo trim($slider_id); ?>" class="master-slider-parent msl ms-parent-id-1">
						<div id="<?php echo trim($slider_id); ?>" class="master-slider ms-skin-default">

							<?php

							/* if custom image slider */
							if ( isset( $custom_banner_temp ) && $custom_banner_temp == 1 ) {
								if ( is_array( $slider_image ) ) {
									for ( $i = 0;$i < count( $slider_image );$i++ ) :
										/* image for WPML */
										if ( function_exists( 'icl_register_string' ) ) {
											icl_register_string( 'livemagazine',$slider_args['widget_id'] . 'silder_image' . $i,$slider_image[ $i ] );
											$slider_image[ $i ] = icl_t( 'livemagazine',$slider_args['widget_id'] . 'silder_image' . $i,$slider_image[ $i ] );
										}

										/* link for WPML */
										if ( function_exists( 'icl_register_string' ) ) {
											icl_register_string( 'livemagazine',$slider_args['widget_id'] . 'silder_link' . $i,$slider_title_link[ $i ] );
											$slider_title_link[ $i ] = icl_t( 'livemagazine',$slider_args['widget_id'] . 'silder_link' . $i,$slider_title_link[ $i ] );
										}

										if ( $slider_image[ $i ] != '' ) : ?>
											<div  class="ms-slide" data-delay="3" data-fill-mode="fill">
												<?php

												/* add link to image */
												echo '<div class="slider_imgs">';
												if ( $slider_title_link[ $i ] ) {
													echo '<a href="' . $slider_title_link[ $i ] . '">';
												}

												echo '<img data-src="' . $slider_image[ $i ] . '" src="' . $slider_image[ $i ] . '" alt="' . $slider_image[ $i ] . '" />';

												if ( $slider_title_link[ $i ] ) {
													echo '</a>';
												}
												echo '</div>';

												?>

												<div class="details">
													<div class="container">
														<?php
														if ( $slider_title[ $i ] != '' ) :
															/* slider title for WPML */
															if ( function_exists( 'icl_register_string' ) ) {
																icl_register_string( 'livemagazine',$slider_args['widget_id'] . 'silder_title' . $i,$slider_title[ $i ] );
																$slider_title[ $i ] = icl_t( 'livemagazine',$slider_args['widget_id'] . 'silder_title' . $i,$slider_title[ $i ] );
															}
															if ( $slider_title_link[ $i ] ) {
																echo '<a href="' . $slider_title_link[ $i ] . '">';
															}

															echo '<h2 class="megaheading">' . $slider_title[ $i ] . '</h2>';

															if ( $slider_title_link[ $i ] ) {
																echo '</a>';
															}
														endif;

														?>
													</div>
												</div>
											</div>
											<?php
										endif;
									endfor; /* for loop finished */
								}// End if().
							} else {

								/* get selected categories */
								if ( is_array( $post_category ) && count( $post_category ) > 0 ) {
									$cat_id = rtrim( implode( ',',$post_category ),',' );
								} else {
									$cat_id = $post_category;
								}
															$slide = new WP_Query( "cat=$cat_id" );

								if ( $slide->have_posts() ) {

									while ( $slide->have_posts() ) : $slide->the_post();
										global $post; ?>

																	<div  class="ms-slide" data-delay="3" data-fill-mode="fill">
																		<?php

																		/* add link to image */
																		echo '<div class="slider_imgs">';
																		//echo '<a href="'.get_permalink(get_the_ID()).'">';
																		if ( has_post_thumbnail() ) {
																			the_post_thumbnail();
																		} else {
																			echo '<img src="' . esc_url( get_stylesheet_directory_uri() ) . '/images/noimage-300x200.png" />';
																		}
																		//echo '</a>';
																		echo '</div>';

																		/* get first category attached to post */
																		$category = get_the_category();
																		$categoryname = $category[0]->cat_name;

																		?>

																		<div class="details">
												<div class="container">
													<?php
														/*
														 * Shows category name for the post
														 * This will show first category name if post is assigned to multiple categories
														 */
													if ( $categoryname ) {
														echo '<span class="label lbl-blue">' . $categoryname . '</span>';
													}

													?>
													<h2 class="megaheading"><a href="<?php echo get_permalink( get_the_ID() ); ?>"><?php the_title(); ?></a></h2>
													<?php
													global $legnth_content;
													$legnth_content = $content_len;

													if ( class_exists( 'woocommerce' ) && $post_type == 'product' ) {
														echo '<p class="desc">' . get_the_excerpt() . '</p>';
													} else {
														echo '<p class="desc">' . get_the_excerpt() . '</p>';
													}
													?>
													<!--<p class="desc">Featured Posts Slider. Add to the top of any Post or Page. Use it to feature Posts or Pages you want your visitors to see. Show 1 or more Posts or Pages.</p>-->


													<p class="meta-info">
														<?php
															tmpl_display_post_meta_boxes( $post );
														?>
													</p>
												</div>
											</div>
										</div>

									<?php
									endwhile;

								}// End if().
							}// End if().
							?>

						</div>
					</div>
				</div>
				 <!-- Initialize Swiper -->


				<script>
			   (function ( $ ) {
						"use strict";

						$(function () {
							var masterslider = new MasterSlider();

							// slider controls
							masterslider.control('arrows'     ,{ autohide:false, overVideo:true  });
							//masterslider_e078.control('bullets'    ,{ autohide:false, overVideo:true, dir:'h', align:'bottom' , margin:10, rtl : true, });

							//masterslider_e078.control('thumblist'  ,{ autohide:false, overVideo:true, dir:'h', speed:17, inset:false, arrows:false, hover:false, customClass:'', align:'bottom',type:'thumbs', margin:5, width:140, height:80, space:5, fillMode:'fill' ,rtl : true, });
							// slider setup

							masterslider.setup("<?php echo trim($slider_id); ?>", {
									width           : 1920,
									height          : 700,
									minHeight       : 0,
									fullwidth		: false,
									space           : 0,
									start           : 1,
									grabCursor      : true,
									swipe           : true,
									mouse           : true,
									layout          : "boxed",
									wheel           : false,
									autoplay        : true,
									instantStartLayers:true,
									loop            : false,
									shuffle         : false,
									preload         : 0,
									heightLimit     : true,
									autoHeight      : false,
									smoothHeight    : true,
									endPause        : false,
									overPause       : true,
									fillMode        : "fill",
									centerControls  : true,
									startOnAppear   : false,
									layersMode      : "center",
									hideLayers      : false,
									fullscreenMargin: 0,
									speed           : <?php echo trim($animation_speed); ?>,
									dir             : "h",
									parallaxMode    : 'swipe',
									view            : '<?php echo trim($animation); ?>',
							});


							window.masterslider_instances = window.masterslider_instances || [];
							window.masterslider_instances.push( masterslider );
						 });

					})(jQuery);
				</script>
				 <!-- Swiper JS -->
				<!--<script src="js/jquery.easing.min.js"></script>-->
				<script src="<?php echo get_template_directory_uri(); ?>/js/masterslider.min.js"></script>

			<?php
			echo trim($slider_args['after_widget']);
		}

		/**
		 * Handles updating settings for the current Slider widget instance.
		 *
		 * @since 2.8.0
		 * @access public
		 *
		 */

		function update( $new_instance, $old_instance ) {
			return $new_instance;
		}

		/**
		 * Outputs the Slider widget settings form.
		 *
		 * @since 2.8.0
		 * @access public
		 *
		 * @param array $instance Current settings.
		 */
		function form( $instance ) {

			$slider_args = array(
							'slider_image'  	=> array(
													get_template_directory_uri() . '/images/slider-images/slide1.jpg',
													get_template_directory_uri() . '/images/slider-images/slide2.jpg',
													get_template_directory_uri() . '/images/slider-images/slide3.jpg',
													get_template_directory_uri() . '/images/slider-images/slide4.jpg',
												),
							'slider_title'  	=> array(
													__( 'Slider Title 1','livemagazine' ),
													__( 'Slider Title 2','livemagazine' ),
													__( 'Slider Title 3','livemagazine' ),
													__( 'Slider Title 4','livemagazine' ),
												),
							'slider_title_link' 	=> array( '#','#','#','#' ),
						);

			$instance = wp_parse_args( (array) $instance, $slider_args );

			// Widget Get Posts settings
			$title              = strip_tags( $instance['title'] );
			$sdesc              = ( isset( $instance['sdesc'] ) ) ? strip_tags( $instance['sdesc'] ) : '';
			$custom_banner_temp = strip_tags( $instance['custom_banner_temp'] ); //(isset( $instance['custom_banner_temp'] )) ? strip_tags( $instance['custom_banner_temp'] ) : '';
			$post_category		= $instance['post_category'];
			$number             = strip_tags( $instance['number'] );
			$content            = empty( $instance['content'] )? '' : strip_tags( $instance['content'] );
			$content_len = empty( $instance['content_len'] )? '60' : strip_tags( $instance['content_len'] );

			// Slider Basic Settings
			$animation         = empty( $instance['animation'] )? 'basic' : strip_tags( $instance['animation'] );
			$animation_speed   = empty( $instance['animation_speed'] )? '17' : strip_tags( $instance['animation_speed'] );

			//  If Custom Banner Slider (Settings)
			$slider_image            = ($instance['slider_image']);
			$slider_title      = ($instance['slider_title']);
			$slider_title_link = ($instance['slider_title_link']); ?>
			<script type="text/javascript">
				function select_custom_image(id,div_custom,div_def){
					var checked=id.checked;
					if(checked){
						jQuery('#'+div_def).slideToggle('slow');
						jQuery('#'+div_custom).slideToggle('slow');
					}else{
						jQuery('#'+div_custom).hide();
						jQuery('#'+div_def).show();
					}
				}
				function select_is_Carousel(id,div_def){
					var checked=id.checked;
					jQuery('#'+div_def).slideToggle('slow');
				}
			</script>
			<p>
			  <label for="<?php echo trim($this->get_field_id( 'title' )); ?>">
				<?php echo __( 'Slider Title','livemagazine' ); ?>
				:
				<input class="widefat" id="<?php echo trim($this->get_field_id( 'title' )); ?>" name="<?php echo trim($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
			  </label>
			</p>

			<p>
			  <label for="<?php echo trim($this->get_field_id( 'animation' )); ?>">
				<?php echo __( 'Animation','livemagazine' ); ?>
				:
				<select class="widefat" name="<?php echo trim($this->get_field_name( 'animation' )); ?>" id="<?php echo trim($this->get_field_id( 'animation' )); ?>">
				  <option <?php
					if ( esc_attr( $animation ) == 'fade' ) {?> selected="selected"<?php }?> value="fade">
					<?php echo __( 'Fade','livemagazine' );?>
				  </option>
				  <option <?php
					if ( esc_attr( $animation ) == 'basic' ) {?> selected="selected"<?php }?> value="basic">
					<?php echo __( 'Slide','livemagazine' );?>
				  </option>
				</select>
			  </label>
			</p>

			<p>
				<label for="<?php echo trim($this->get_field_id( 'animation_speed' )); ?>"><?php echo __( 'Slide Changing Speed','livemagazine' ); ?>:
					<input class="widefat" id="<?php echo trim($this->get_field_id( 'animation_speed' )); ?>" name="<?php echo trim($this->get_field_name( 'animation_speed' )); ?>" type="text" value="<?php echo esc_attr( $animation_speed ); ?>" />
				</label>
				<b>
					<?php echo __( 'It accepts float values between 0 and 100.','livemagazine' );?>
				</b>
			</p>
			<p>
			<label for="<?php echo trim($this->get_field_id( 'content' )); ?>">
			  <input <?php
				if ( $content ) {
					echo 'checked=checked';
				}?> id="<?php echo trim($this->get_field_id( 'content' )); ?>" name="<?php echo trim($this->get_field_name( 'content' )); ?>" type="checkbox" value="1"/>
			  <b>
				<?php echo __( 'Enable Post Excerpt In Slider','livemagazine' );?>
			  </b> </label>
			</p>

			<div id="<?php echo trim($this->get_field_id( 'home_slide_default_temp' )); ?>" style="<?php
			if ( $custom_banner_temp == '1' ) { ?>display:none;<?php } else { ?>display:block;<?php }?>">
			  <p>
				<label for="<?php echo trim($this->get_field_id( 'post_category' ));?>" >
					<?php echo __( 'Select Category','livemagazine' );?>
				  <select id="<?php echo trim($this->get_field_id( 'post_category' )); ?>" name="<?php echo trim($this->get_field_name( 'post_category' )); ?>[]" class="widefat"  multiple="multiple" size="8">
					<?php $taxonomies = get_taxonomies( array(
						'public' => true,
					), 'objects' );

					foreach ( $taxonomies as $taxonomy ) {
						$query_label = '';
						if ( ! empty( $taxonomy->query_var ) ) {
							$query_label = $taxonomy->query_var;
						} else { $query_label = $taxonomy->name;
						}

						if ( $taxonomy->labels->name != 'Tags' && $taxonomy->labels->name != 'Format' && ! strstr( $taxonomy->labels->name,'tag' ) && ! strstr( $taxonomy->labels->name,'Tags' ) && ! strstr( $taxonomy->labels->name,'format' ) && ! strstr( $taxonomy->labels->name,'Shipping Classes' )&& ! strstr( $taxonomy->labels->name,'Order statuses' )&& ! strstr( $taxonomy->labels->name,'genre' )&& ! strstr( $taxonomy->labels->name,'platform' ) && ! strstr( $taxonomy->labels->name,'colour' ) && ! strstr( $taxonomy->labels->name,'size' ) ) :
							?>
							<optgroup label="<?php echo esc_attr( $taxonomy->object_type[0] ) . '-' . esc_attr( $taxonomy->labels->name ); ?>">
							<?php
							$terms = get_terms( $taxonomy->name, 'orderby=name&hide_empty=0' );
							foreach ( $terms as $term ) { ?>
										<option style="margin-left: 8px; padding-right:10px;" value="<?php echo trim($term->term_id); ?>" <?php if ( isset( $term->term_id ) && ! empty( $post_category ) && in_array( trim( $term->term_id ),$post_category ) ) { echo 'selected';}?>>
											<?php echo '-' . esc_attr( $term->name ); ?>
										</option>
									<?php
							} ?>
								</optgroup>
							<?php
							endif;
					}?>
				  </select>
				</label>
				<small>
				<?php echo __( 'Select the categories from the post types.','livemagazine' );?>
				</small> </p>
			<p>
			<label for="<?php echo trim($this->get_field_id( 'number' )); ?>">
				<?php echo __( 'Number of posts:','livemagazine' );?>
			  <input class="widefat" id="<?php echo trim($this->get_field_id( 'number' )); ?>" name="<?php echo trim($this->get_field_name( 'number' )); ?>" type="text" value="<?php echo esc_attr( $number ); ?>" />
			</label>
			</p>
			<p>
			<label for="<?php echo trim($this->get_field_id( 'content_len' )); ?>">
				<?php echo __( 'Excerpt Length:','livemagazine' );?>
			  <input class="widefat" id="<?php echo trim($this->get_field_id( 'content_len' )); ?>" name="<?php echo trim($this->get_field_name( 'content_len' )); ?>" type="text" value="<?php echo esc_attr( $content_len ); ?>" />
			</label>
			</p>

			</div>

			<p> <br/>
			<label for="<?php echo trim($this->get_field_id( 'custom_banner_temp' )); ?>">
			<input id="<?php echo trim($this->get_field_id( 'custom_banner_temp' )); ?>" name="<?php echo trim($this->get_field_name( 'custom_banner_temp' )); ?>" type="checkbox" value="1" <?php
			if ( $custom_banner_temp == '1' ) {
				?>  checked="checked"  <?php
			} ?>  onclick="select_custom_image(this,'<?php echo trim($this->get_field_id( 'home_slide_custom_temp' )); ?>','<?php echo trim($this->get_field_id( 'home_slide_default_temp' )); ?>');" />
			&nbsp;
			<?php echo __( '<b>Use Custom Images?</b>','livemagazine' );?>
			<br/>
			</label>
			<br/>
			</p>
			<div id="<?php echo trim($this->get_field_id( 'home_slide_custom_temp' )); ?>" class="<?php echo 'home_slide_custom_temp'; ?>" style="<?php
			if ( $custom_banner_temp == '1' ) { ?>display:block;<?php } else { ?>display:none;<?php }?>">
			  <div id="TextBoxesGroup" class="TextBoxesGroup">
				<div id="TextBoxDiv1" class="TextBoxDiv1">
					<?php	do_action( 'tmpl_before_slider_title',$instance,$this );	?>
				  <p>
					<?php global $textbox_title;
										$textbox_title = $this->get_field_name( 'slider_title' );
										?>
					<label for="<?php echo trim($this->get_field_id( 'slider_title' )); ?>">
						<?php echo __( 'Banner Slider Title 1','livemagazine' );?>
					  <input type="text" class="widefat"  name="<?php echo trim($textbox_title); ?>[]" value="<?php echo esc_attr( $slider_title[0] ); ?>">
					</label>
				  </p>
					<?php
									do_action( 'tmpl_after_slider_title',$instance,$this );
									?>
				  <p>
					<?php global $textbox_title_link;
										$textbox_title_link = $this->get_field_name( 'slider_title_link' );
										?>
					<label for="<?php echo trim($this->get_field_id( 'slider_title_link' )); ?>">
						<?php echo __( 'Banner Slider Title Link 1','livemagazine' );?>
					  <input type="text" class="widefat"  name="<?php echo trim($textbox_title_link); ?>[]" value="<?php echo esc_attr( $slider_title_link[0] ); ?>">
					</label>
				  </p>
				  <p>
					<?php global $textbox_name;
										$textbox_name = $this->get_field_name( 'slider_image' );
										?>
					<label for="<?php echo trim($this->get_field_id( 'slider_image' )); ?>">
						<?php echo __( 'Banner Slider Image 1 full URL <small>(ex.//templatic.com/images/banner1.png )</small>  :','livemagazine' );?>
					  <input type="text" class="widefat"  name="<?php echo trim($textbox_name); ?>[]" value="<?php echo esc_attr( $slider_image[0] ); ?>">
					</label>
				  </p>
				</div>
				<?php
				for ( $i = 1;$i < count( $slider_image );$i++ ) {
					if ( $slider_image[ $i ] != '' ) {
						$j = $i + 1;
						echo '<div  class="TextBoxDiv' . $j . '">';
						echo '<p>';
						echo '<label>' . __( 'Banner Slider Title','livemagazine' ) . $j;
						echo ' <input type="text" class="widefat"  name="' . $textbox_title . '[]" value="' . esc_attr( $slider_title[ $i ] ) . '">';
						echo '</label>';
						echo '</p>';
						do_action( 'tmpl_image_link',$j,$instance,$this );
						echo '<p>';
						echo '<label>' . __( 'Banner Slider Title Link','livemagazine' ) . $j;
						echo ' <input type="text" class="widefat"  name="' . $textbox_title_link . '[]" value="' . esc_attr( $slider_title_link[ $i ] ) . '">';
						echo '</label>';
						echo '</p>';
						echo '<p>';
						echo '<label>' . sprintf( __( 'Banner Slider Image %s full URL','livemagazine' ),$j );
						echo ' <input type="text" class="widefat"  name="' . $textbox_name . '[]" value="' . esc_attr( $slider_image[ $i ] ) . '">';
						echo '</label>';
						echo '</p>';
						echo '</div>';
					}
				}	?>
			  </div>
			  <a href="javascript:void(0);" id="addButton" class="addButton" onclick="add_textbox('<?php echo trim($textbox_name);?>','<?php echo trim($textbox_title_link); ?>','<?php echo trim($textbox_title);?>');"> <?php echo __( '+Add more','livemagazine' ); ?> </a> &nbsp; | &nbsp;
			  <a	href="javascript:void(0);" id="removeButton" class="removeButton" onclick="remove_textbox();"><?php echo __( '-Remove','livemagazine' ); ?> </a>
			</div>
			<?php
		}
	}
	/*
	* templatic Slider widget init
	*/
	add_action( 'admin_footer','supreme_multitext_box' );
	add_action( 'customize_controls_enqueue_scripts','supreme_multitext_box',999 );
	function supreme_multitext_box() {
		global $textbox_name,$textbox_title_link,$textbox_title;
		?>
		<script type="application/javascript">
			var banner_counter = 2;
			function add_textbox(name,title_link,title)
			{
				var BannerNewTextBoxDiv = jQuery(document.createElement('div')).attr("class", 'TextBoxDiv' + banner_counter);
				BannerNewTextBoxDiv.html('<p><label>Banner Slider Title '+ banner_counter + ' </label>'+'<input type="text" class="widefat" name="'+title+'[]" id="textbox' + banner_counter + '" value="" ></p><p><label>Banner Slider Title Link '+ banner_counter + ' </label>'+'<input type="text" class="widefat" name="'+title_link+'[]" id="textbox' + banner_counter + '" value="" ></p><p><label>Banner Slider Image '+ banner_counter + ' full URL : </label>'+'<input type="text" class="widefat" name="'+name+'[]" id="textbox' + banner_counter + '" value="" ></p>');
				BannerNewTextBoxDiv.appendTo(".TextBoxesGroup");
				banner_counter++;
			}
			function remove_textbox()
			{
				if(banner_counter-1==1)
				{
					alert("<?php echo __( 'One textbox required.','livemagazine' ); ?>");
					return false;
				}
				banner_counter--;
				jQuery(".TextBoxDiv" + banner_counter).remove();
			}
		</script>
	<?php
	}
}// End if().
/* EOF */
?>
