<?php
/**
 * Latest Posts
 *
 */
class Tmpl_Widget_Latest_Posts extends WP_Widget {

	/**
	 * Sets up a new Latest Posts widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 */

	function __construct() {
		$widget_ops = array(
			'classname' => 'tmpl_widget_latest_posts',
			'description' => __( 'Show your latest posts.','livemagazine' ),
		);
		parent::__construct( 'Tmpl_Widget_Latest_Posts', __( 'T &rarr; Latest Posts','livemagazine' ), $widget_ops );
		$this->alt_option_name = 'tmpl_widget_latest_posts';
	}

	/**
	 * Outputs the content for the current Latest Posts widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 */
	function widget( $args, $instance ) {
		ob_start();

		extract( $args, EXTR_SKIP );
		echo trim($args['before_widget']);
		$title = empty( $instance['title'] ) ? '' : apply_filters( 'widget_title', $instance['title'] );

		 $category = empty( $instance['category'] ) ? '' : apply_filters( 'widget_category', $instance['category'] );
		$post_number = empty( $instance['number'] ) ? '4' : apply_filters( 'widget_post_number', $instance['number'] );
		$show_excerpt = empty( $instance['show_excerpt'] ) ? '' : apply_filters( 'widget_show_excerpt', $instance['show_excerpt'] );
		$view = empty( $instance['view'] ) ? 'list' : apply_filters( 'widget_show_view', $instance['view'] );
		$post_type = empty( $instance['post_type'] ) ? 'post' : apply_filters( 'widget_post_type', $instance['post_type'] );
		$orderby = empty( $instance['orderby'] ) ? 'ID' : apply_filters( 'widget_post_orderby', $instance['orderby'] );
		$order = empty( $instance['order'] ) ? 'DESC' : apply_filters( 'widget_post_order', $instance['order'] );
		$image_size = empty( $instance['image_size'] ) ? 'thumbnail' : apply_filters( 'widget_image_size', $instance['image_size'] );

		if ( $view == 'grid' ) { $class = 'grid';
		} else { $class = 'list'; }
		echo '';

		$catCounter = 0;
		$pcount = 0;
		if ( $title ) {
			echo trim($args['before_title'] . $title . $args['after_title']);
		} ?>
		 <!-- Article start -->

			<?php

			global $wpdb;
			/* qet transient of category results - save results in cache */

			$taxonomies = get_object_taxonomies( (object) array(
				'post_type' => $post_type,
				'public' => true,
				'_builtin' => true,
			) );
			/* qet transient of category results - save results in cache */
			if ( function_exists( 'icl_object_id' ) ) {
				foreach ( $category as $key => $value ) {
					$category[ $key ] = icl_object_id( $value, $taxonomies[0], true );
				}
			}

			/* get category slug */
			$category = implode( ',',$category );

			if ( ! empty( $category ) ) {
				$lp = new WP_Query( array(
					'post_type' => $post_type,
						'posts_per_page' => $post_number,
						'category_name' => $category,
						'orderby' => $orderby,
					'order' => $order,
				) ); /* Query to fetch per view */
			} else {
				$lp = new WP_Query( array(
					'post_type' => $post_type,
						 'posts_per_page' => $post_number,
						 'orderby' => $orderby,
					'order' => $order,
				) ); /* Query to fetch per view */
			}

			global $post;
			if ( $lp->have_posts() ) {

				echo '<div class="row list-articles ' . $class . '">';
				if ( $image_size == 'thumbnail' ) {
					echo '<ul class="list-picks">';
				}
				while ( $lp->have_posts() ) {

					$lp->the_post();

					if ( $image_size == 'thumbnail' ) { ?>
					
						
							<li class="picks-details">
								<div class="picks-image">
								<?php
									echo '<a class="list-post-img" href="' . get_permalink( get_the_ID() ) . '">';
								if ( has_post_thumbnail() ) {
									the_post_thumbnail( $image_size );
								} else {
									echo '<img height="55" width="85" src="' . esc_url( get_stylesheet_directory_uri() ) . '/images/noimage-300x200.png" />';
								}
									echo '</a>';
								?>
								</div>
								<div class="picks-content">
									<h4 class="item-title"><a href="<?php echo get_permalink( get_the_ID() ); ?>"><?php the_title(); ?></a></h4>
									<p class="meta-info">
										<?php
											/* get publish date */
											$publish_date = get_the_date();
										if ( $publish_date ) {
											echo '<span class="date">' . $publish_date . '</span> ';
										}
										?>	
									</p>
								</div>
							</li>

												
					<?php
					} else { ?>
						<article class="col-md-6 col-sm-12 col-xs-12 post recent-post">
							<?php if ( $view == 'grid' ) : ?><h3 class="post-title"><a href="<?php echo get_permalink( get_the_ID() ); ?>"><?php the_title(); ?></a></h3><?php endif; ?>
							<?php
								echo '<a class="list-post-img" href="' . get_permalink( get_the_ID() ) . '">';
							if ( has_post_thumbnail() ) {
								the_post_thumbnail( $image_size );
							} else {
								echo '<img src="' . esc_url( get_stylesheet_directory_uri() ) . '/images/noimage-300x200.png" />';
							}
								echo '</a>';
							?>
							<div class="item-content">
								<?php if ( $view == 'list' ) : ?><h3 class="post-title"><a href="<?php echo get_permalink( get_the_ID() ); ?>"><?php the_title(); ?></a></h3><?php endif; ?>
								<p class="meta-info">
									<?php
										tmpl_display_post_meta_boxes( $post );
									?>
								</p>
								
								<?php

									$excerpt = get_the_excerpt();
								if ( $show_excerpt ) {
									echo '<p class="post-excerpt">' . get_the_excerpt() . '</p>';
								}

								?>
							</div>
								
						</article>
						<?php
					}// End if().
				}// End while().

				if ( $image_size == 'thumbnail' ) {
					echo '</ul>';
				}
				echo '</div>';
			}// End if().

			echo trim($args['after_widget']);
	}

	/**
	 * Handles updating settings for the current Latest Posts widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 */

	function update( $new_instance, $old_instance ) {
		global $wpdb;
		$instance = $old_instance;
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['category'] = $new_instance['category'];
		$instance['number'] = strip_tags( $new_instance['number'] );
		$instance['show_excerpt'] = strip_tags( $new_instance['show_excerpt'] );
		$instance['view'] = strip_tags( $new_instance['view'] );
		$instance['orderby'] = strip_tags( $new_instance['orderby'] );
		$instance['order'] = strip_tags( $new_instance['order'] );
		$instance['image_size'] = strip_tags( $new_instance['image_size'] );

		return $instance;
	}

	/**
	 * Outputs the Latest Posts widget settings form.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	function form( $instance ) {

		//widgetform in backend
		$instance = wp_parse_args( (array) $instance, array(
			'title' => '',
			'category' => '',
			'number' => '',
		) );
		$title = strip_tags( $instance['title'] );
		$category = $instance['category'];
		$number = strip_tags( $instance['number'] );
		$show_excerpt = strip_tags( $instance['show_excerpt'] );
		$view = strip_tags( $instance['view'] );
		$image_size = strip_tags( $instance['image_size'] );
		$orderby = strip_tags( $instance['orderby'] );
		$order = strip_tags( $instance['order'] );
		$post_type = 'post';

		?>
		<p>
			<label for="<?php echo trim($this->get_field_id( 'title' )); ?>"><?php _e( 'Title:','livemagazine' ); ?></label>
			<input class="widefat" id="<?php echo trim($this->get_field_id( 'title' )); ?>" name="<?php echo trim($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo trim($title); ?>" />
		</p>

		<p>
			<label for="<?php echo trim($this->get_field_id( 'number' )); ?>"><?php _e( 'Number of posts to show','livemagazine' ); ?>: </label>
			<input id="<?php echo trim($this->get_field_id( 'number' )); ?>" name="<?php echo trim($this->get_field_name( 'number' )); ?>" type="text" value="<?php echo trim($number); ?>" size="3" />
		</p>

		 <!-- Select the view -->
		 <p>
			 <label for="<?php echo trim($this->get_field_id( 'view' ));  ?>"><?php _e( 'Select view: <b>(not applicable in sidebars and when thumbnail is selected )</b> ','livemagazine' ); ?></label>  
			 <select class="widefat" name="<?php echo trim($this->get_field_name( 'view' )); ?>" id="<?php  echo trim($this->get_field_id( 'view' )); ?>" >
				 <option value="list" <?php if ( $view == 'list' ) { echo 'selected=selected'; }?>><?php _e( 'List','livemagazine' ); ?></option>
				 <option value="grid" <?php if ( $view == 'grid' ) { echo 'selected=selected'; }?>><?php _e( 'Grid','livemagazine' ); ?></option>
			 </select>
		 </p>
		 <!-- Select post type option in back end -->

						 <p>
			<input class="checkbox" type="checkbox" <?php checked( $show_excerpt ); ?> id="<?php echo trim($this->get_field_id( 'show_excerpt' )); ?>" name="<?php echo trim($this->get_field_name( 'show_excerpt' )); ?>" value="1"/>
		
			<label for="<?php echo trim($this->get_field_id( 'show_excerpt' )); ?>"><?php _e( 'Display post excerpt?','livemagazine' ); ?></label>
			<p class="description"><?php _e( 'Excerpt content only show with list view.','livemagazine' ); ?></p>
			
		</p>

		<p> 
		  <label for="<?php echo trim($this->get_field_id( 'category' )); ?>"><?php _e( 'Categories ','livemagazine' ); ?>: </label>
		  <select class="widefat" id="<?php echo trim($this->get_field_id( 'category' )); ?>" name="<?php echo trim($this->get_field_name( 'category' )); ?>[]" multiple=multiple>
					<?php
					$args = array();
					if ( $post_type == 'post' ) { $category_slug = 'category'; }
					$terms_obj = get_terms( $category_slug, $args );
					foreach ( $terms_obj as $terms ) {
						if ( $terms->slug != '' ) {
							if ( is_array( $category ) && in_array( $terms->slug,$category ) ) { $selected = 'selected=selected';
							} else {  $selected = ''; }
							?>
						  <option value="<?php echo trim($terms->slug); ?>" <?php echo trim($selected); ?>><?php echo trim($terms->name); ?></option>
						<?php  }
					}
					?>		  		
		  </select>
		  <p class="description"><?php _e( 'Select categories from which you want the posts to appear in this widget.','livemagazine' ); ?></p>
		 </p>
		 
		 <p>
			<label for="<?php echo trim($this->get_field_id( 'orderby' )); ?>"><?php echo __( 'Order By', 'livemagazine' ); ?>: </label>
			<select id="<?php echo trim($this->get_field_id( 'orderby' )); ?>" name="<?php echo trim($this->get_field_name( 'orderby' )); ?>">
				<option style="padding-right:10px;" value="date" <?php selected( 'date', $instance['orderby'] ); ?>>
					<?php echo __( 'Date', 'livemagazine' ); ?>
				</option>
				<option style="padding-right:10px;" value="title" <?php selected( 'title', $instance['orderby'] ); ?>>
					<?php echo __( 'Title', 'livemagazine' ); ?>
				</option>
				<option style="padding-right:10px;" value="ID" <?php selected( 'ID', $instance['orderby'] ); ?>>
					<?php echo __( 'ID', 'livemagazine' ); ?>
				</option>
				<option style="padding-right:10px;" value="comment_count" <?php selected( 'comment_count', $instance['orderby'] ); ?>>
					<?php echo __( 'Comment Count', 'livemagazine' ); ?>
				</option>
				<option style="padding-right:10px;" value="rand" <?php selected( 'rand', $instance['orderby'] ); ?>>
					<?php echo __( 'Random', 'livemagazine' ); ?>
				</option>
			</select>
		</p>
		
		<p>
			<label for="<?php echo trim($this->get_field_id( 'order' )); ?>"><?php echo __( 'Sort Order', 'livemagazine' ); ?>: </label>
			<select id="<?php echo trim($this->get_field_id( 'order' )); ?>" name="<?php echo trim($this->get_field_name( 'order' )); ?>">
				<option style="padding-right:10px;" value="DESC" <?php selected( 'DESC', $instance['order'] ); ?>>
					<?php echo __( 'Descending (3, 2, 1)', 'livemagazine' ); ?>
				</option>
				<option style="padding-right:10px;" value="ASC" <?php selected( 'ASC', $instance['order'] ); ?>>
					<?php echo __( 'Ascending (1, 2, 3)', 'livemagazine' ); ?>
				</option>
			</select>
		</p>
		 
		 <p>
			<label for="<?php echo trim($this->get_field_id( 'image_size' )); ?>"><?php echo _e( 'Image Size', 'livemagazine' ); ?>: </label>

			<?php

				/* get all default image sizes  */
				$def_sizes = get_intermediate_image_sizes();
			foreach ( $def_sizes as $_size ) {
				if ( in_array( $_size, array( 'thumbnail', 'medium', 'medium_large', 'large' ) ) ) {
					$sizes1[ $_size ]['width']  = get_option( "{$_size}_size_w" );
					$sizes1[ $_size ]['height'] = get_option( "{$_size}_size_h" );
					$sizes1[ $_size ]['crop']   = (bool) get_option( "{$_size}_crop" );
				}
			}

				/* get all additional image sizes */
				global $_wp_additional_image_sizes;
			if ( $_wp_additional_image_sizes ) {
				$sizes = $_wp_additional_image_sizes;
			} else {
				$sizes = array();
			}

				/* merge all image sizes */
			if ( ! empty( $sizes ) ) {
				$sizes = array_merge( $sizes1,$sizes );
			}

			?>
			
			<select id="<?php echo trim($this->get_field_id( 'image_size' )); ?>" name="<?php echo trim($this->get_field_name( 'image_size' )); ?>">
				<option style="padding-right:10px;" value="thumbnail"><?php echo __( 'thumb', 'livemagazine' ); ?>(<?php echo get_option( 'thumbnail_size_w' ); ?>x<?php echo get_option( 'thumbnail_size_h' ); ?>)</option>
				<?php
				foreach ( (array) $sizes as $name => $size ) :
					echo '<option style="padding-right: 10px;" value="' . esc_attr( $name ) . '" ' . selected( $name, $instance['image_size'], false ) . '>' . esc_html( $name ) . ' (' . $size['width'] . 'x' . $size['height'] . ')</option>';
					endforeach;
					?>
			</select>
			</p>
		<?php
	}
}
/* EOF */
?>
