<?php
/*
*
* Video Category Widget
*/
class Tmpl_Widget_Magazine_Categories extends WP_Widget {

	/**
	 * Sets up a new Categories widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 */


	function __construct() {
		$widget_ops = array(
			'classname' => 'tmpl_widget_magazine_categories',
			'description' => __( 'A list or dropdown of categories.','livemagazine' ),
		);
		parent::__construct( 'Tmpl_Widget_Magazine_Categories', __( 'T &rarr; Categories','livemagazine' ), $widget_ops );
	}

	/**
	 * Outputs the content for the current Categories widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 */
	function widget( $args, $instance ) {
		extract( $args );

		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? __( 'Categories','livemagazine' ) : $instance['title'], $instance, $this->id_base );
		$c = ! empty( $instance['count'] ) ? '1' : '0';
		$h = ! empty( $instance['hierarchical'] ) ? '1' : '0';
		$d = ! empty( $instance['dropdown'] ) ? '1' : '0';
		$n = ! empty( $instance['number'] ) ? $instance['number'] : '10';

		echo trim($args['before_widget']);
		if ( $title ) {
			echo trim($args['before_title'] . $title . $args['after_title']);
		}

		$cat_args = array(
			'orderby' => 'ID',
			'show_count' => $c,
			'hierarchical' => $h,
			'number' => $n,
		);

		/* filter for category dropdown this filter is in same file */
		//add_filter('wp_dropdown_cats','tmpl_wp_dropdown_cats',10,2);

		if ( $d ) {

			$tmpl_rand_id = 'tmpl_widget_' . rand( 1,999 );

			$cat_args['id'] = $tmpl_rand_id;
			$cat_args['name'] = 'dropcat';
			$cat_args['show_option_none'] = __( 'Select Category','livemagazine' );
			$cat_args['class'] = 'form-control';
			wp_dropdown_categories( apply_filters( 'widget_categories_dropdown_args', $cat_args ) );
?>

			<script type='text/javascript'>
						
				jQuery(document).ready(function(){
					jQuery('#<?php echo trim($tmpl_rand_id); ?> option').each(function(){
						if(jQuery(this).text() == '<?php single_cat_title(); ?>')
						{
							jQuery(this).attr('selected','selected');
						}
					
					});
					jQuery(document).on('change','#<?php echo trim($tmpl_rand_id); ?>', function(){
							
							var cat_id = jQuery(this).val();
							/* for default post type category and tags */
							//if('<?php echo trim($args['taxonomy']);?>' == 'category')
							{
								location.href = "<?php echo trim(home_url()); ?>/?cat="+cat_id;
							}
					
					});
				
				});
			
			</script>

<?php
		} else {
?>
		<ul>
<?php
		$cat_args['title_li'] = '';
		wp_list_categories( apply_filters( 'widget_categories_args', $cat_args ) );
?>
		</ul>
<?php
		}// End if().

		echo trim($args['after_widget']);
	}

	/**
	 * Handles updating settings for the current Categories widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 */

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['count'] = ! empty( $new_instance['count'] ) ? 1 : 0;
		$instance['hierarchical'] = ! empty( $new_instance['hierarchical'] ) ? 1 : 0;
		$instance['dropdown'] = ! empty( $new_instance['dropdown'] ) ? 1 : 0;
		$instance['number'] = ! empty( $new_instance['number'] ) ? $new_instance['number'] : 5;

		return $instance;
	}

	/**
	 * Outputs the Categories widget settings form.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */

	function form( $instance ) {
		//Defaults
		$instance = wp_parse_args( (array) $instance, array(
			'title' => '',
		) );
		$title = esc_attr( $instance['title'] );
		$count = isset( $instance['count'] ) ? (bool) $instance['count'] :false;
		$hierarchical = isset( $instance['hierarchical'] ) ? (bool) $instance['hierarchical'] : false;
		$dropdown = isset( $instance['dropdown'] ) ? (bool) $instance['dropdown'] : false;
		$number = isset( $instance['number'] ) ? $instance['number'] : 10;
?>
		<p><label for="<?php echo trim($this->get_field_id( 'title' )); ?>"><?php _e( 'Title:','livemagazine' ); ?></label>
		<input class="widefat" id="<?php echo trim($this->get_field_id( 'title' )); ?>" name="<?php echo trim($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo trim($title); ?>" /></p>

		<p><input type="checkbox" class="checkbox" id="<?php echo trim($this->get_field_id( 'dropdown' )); ?>" name="<?php echo trim($this->get_field_name( 'dropdown' )); ?>"<?php checked( $dropdown ); ?> />
		<label for="<?php echo trim($this->get_field_id( 'dropdown' )); ?>"><?php _e( 'Display as dropdown','livemagazine' ); ?></label><br />

		<input type="checkbox" class="checkbox" id="<?php echo trim($this->get_field_id( 'count' )); ?>" name="<?php echo trim($this->get_field_name( 'count' )); ?>"<?php checked( $count ); ?> />
		<label for="<?php echo trim($this->get_field_id( 'count' )); ?>"><?php _e( 'Show post counts','livemagazine' ); ?></label><br />

		<input type="checkbox" class="checkbox" id="<?php echo trim($this->get_field_id( 'hierarchical' )); ?>" name="<?php echo trim($this->get_field_name( 'hierarchical' )); ?>"<?php checked( $hierarchical ); ?> />
		<label for="<?php echo trim($this->get_field_id( 'hierarchical' )); ?>"><?php _e( 'Show hierarchy','livemagazine' ); ?></label></p>
		
		<p><label for="<?php echo trim($this->get_field_id( 'number' )); ?>"><?php _e( 'Number of categories','livemagazine' ); ?></label><input type="text" class="text" id="<?php echo trim($this->get_field_id( 'number' )); ?>" name="<?php echo trim($this->get_field_name( 'number' )); ?>" value="<?php echo trim($number); ?>"/></p>
		
<?php
	}

}
/* EOF */
?>
