<?php
/**
 * Latest Posts
 *
 */
class Tmpl_Widget_Most_Recent_post extends WP_Widget {

	/**
	 * Sets up a new Most Recent widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 */

	function __construct() {
		$widget_ops = array(
			'classname' => 'trending-post',
			'description' => __( 'Show your trending posts. This will show only 4 posts as per tags which you defined.','livemagazine' ),
		);
		parent::__construct( 'Tmpl_Widget_Most_Recent_post', __( 'T &rarr; Trending Post','livemagazine' ), $widget_ops );
		$this->alt_option_name = 'Tmpl_Widget_Most_Recent_post';
	}

	/**
	 * Outputs the content for the current Most Recent post widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 */
	function widget( $args, $instance ) {

		extract( $args, EXTR_SKIP );
		echo trim($args['before_widget']);
		$title = empty( $instance['title'] ) ? '' : apply_filters( 'widget_title', $instance['title'] );

		 $category = empty( $instance['category'] ) ? '' : apply_filters( 'widget_category', $instance['category'] );
		$post_number = empty( $instance['number'] ) ? '4' : apply_filters( 'widget_post_number', $instance['number'] );
		$show_excerpt = empty( $instance['show_excerpt'] ) ? '' : apply_filters( 'widget_show_excerpt', $instance['show_excerpt'] );
		$view = empty( $instance['view'] ) ? 'list' : apply_filters( 'widget_show_view', $instance['view'] );
		$post_type = empty( $instance['post_type'] ) ? 'post' : apply_filters( 'widget_post_type', $instance['post_type'] );
		$post_tags = empty( $instance['post_tags'] ) ? 'trending' : apply_filters( 'widget_post_tags', $instance['post_tags'] );
		$link = empty( $instance['link'] ) ? '#' : apply_filters( 'widget_link', $instance['link'] );

		if ( $view == 'grid' ) { $class = 'grid';
		} else { $class = 'list'; }
		echo '';

		$catCounter = 0;
		$pcount = 0;

		echo '<div class="trendin-head">';

			/* widget title */

		if ( $title ) {
			echo trim($args['before_title'] . $title . $args['after_title']);
		}

			/* view more link */
		if ( $link ) {
			echo '<a class="btn btn-primary btn-sm" href="' . $link . '">' . __( 'View All','livemagazine' ) . '</a>';
		}

		echo '</div>';

			global $wpdb;
			/* qet transient of category results - save results in cache */

			$taxonomies = get_object_taxonomies( (object) array(
				'post_type' => $post_type,
				'public' => true,
				'_builtin' => true,
			) );
			/* qet transient of category results - save results in cache */
		if ( function_exists( 'icl_object_id' ) ) {
			foreach ( $category as $key => $value ) {
				$category[ $key ] = icl_object_id( $value, $taxonomies[0], true );
			}
		}

		if ( ! empty( $category ) ) {
			$lp = new WP_Query( array(
				'post_type' => $post_type,
				'posts_per_page' => $post_number,
				'tag' => 'trending',
				'orderby' => 'post_date',
				'order' => 'DESC',
			) ); /* Query to fetch per view */
		} else {
			$lp = new WP_Query(array(
				'post_type' => $post_type,
					'posts_per_page' => $post_number,
					'tag' => $post_tags,
					'orderby' => 'post_date',
					'order' => 'DESC',
					)
			); /* Query to fetch posts as defined tags */
		}

			global $post;
		if ( $lp->have_posts() ) {

			$count = 1; ?>
				<div class="row">
				<?php
				while ( $lp->have_posts() ) {  $lp->the_post();

					/* get first category attached to post */
					$category = get_the_category();
					$categoryname = $category[0]->cat_name;

					/* biggest post */
					if ( $count == 1 ) { ?>
						<div class="col-md-8 col-sm-7 col-xs-12 featured-trend">
							<article class="post trending-article">

									<div class="item-image">
										<?php
										if ( has_post_thumbnail() ) {
											the_post_thumbnail( 'tmpl-most-trending-image' );
										} else {
											echo '<img src="' . esc_url( get_stylesheet_directory_uri() ) . '/images/noimage-780x525.png" />';
										}
										?>
										<div class="content">

											<?php
												/*
												 * Shows category name for the post
												 * This will show first category name if post is assigned to multiple categories
												 */
											if ( $categoryname ) {
												echo '<span class="label lbl-green">' . $categoryname . '</span>';
											}

											?>
											<h4 class="item-title"><a href="<?php echo get_permalink( get_the_ID() ); ?>"><?php the_title(); ?></a></h4>

											<p class="meta-info">
												<?php
													tmpl_display_post_meta_boxes( $post );
												?>
											</p>
										</div>
									</div>

							</article>
						</div>
						<?php
					} else {

						/* smaller post */
						if ( $count == 2 ) { ?>
						<div class="col-md-4 col-sm-5 col-xs-12 trending-article-wrapper">
							<div class="row">
								<div class="col-md-12 col-sm-12 col-xs-12">
									<article class="post trending-article">
										<a href="<?php echo get_permalink( get_the_ID() ); ?>">
											<div class="item-image">
												<?php
												if ( has_post_thumbnail() ) {
													the_post_thumbnail( 'tmpl-medium-size' );
												} else {
													echo '<img src="' . esc_url( get_stylesheet_directory_uri() ) . '/images/noimage-375x255.png" />';
												}
												?>
											</div>
											<div class="content">
												<?php
													/*
													 * Shows category name for the post
													 * This will show first category name if post is assigned to multiple categories
													 */
												if ( $categoryname ) {
													echo '<span class="label lbl-gray">' . $categoryname . '</span>';
												}

												?>
												<h4 class="item-title"><?php the_title(); ?></h4>
											</div>
										</a>
									</article>
								</div>
								<?php
						} elseif ( $count == 3 ) { /* small posts */ ?>

								<div class="col-md-6 col-sm-6 col-xs-6">
									<article class="post trending-article">
										<a href="<?php echo get_permalink( get_the_ID() ); ?>">
											<div class="item-image">
												<?php
												if ( has_post_thumbnail() ) {
													the_post_thumbnail( 'tmpl-posts-thumb' );
												} else {
													echo '<img src="' . esc_url( get_stylesheet_directory_uri() ) . '/images/noimage-175x115.png" />';
												}
												?>
											</div>
											<div class="content">
												<?php
												if ( $categoryname ) {
													echo '<span class="label lbl-green">' . $categoryname . '</span>';
												}

												?>
												<h4 class="item-title"><?php the_title(); ?></h4>
											</div>
										</a>
									</article>
								</div>
							<?php
						} else {
							?>
							<div class="col-md-6 col-sm-6 col-xs-6">
							<article class="post trending-article">
								<a href="<?php echo get_permalink( get_the_ID() ); ?>">
									<div class="item-image">
										<?php
										if ( has_post_thumbnail() ) {
											the_post_thumbnail( 'tmpl-posts-thumb' );
										} else {
											echo '<img src="' . esc_url( get_stylesheet_directory_uri() ) . '/images/noimage-175x115.png" />';
										}
											?>
											</div>
											<div class="content">
											<?php
											/*
											 * Shows category name for the post
											 * This will show first category name if post is assigned to multiple categories
											 */
											if ( $categoryname ) {
												echo '<span class="label lbl-orange">' . $categoryname . '</span>';
											}

											?>
											<h4 class="item-title"><?php the_title(); ?></h4>
											</div>
										</a>
									</article>
								</div>
							</div>
						</div>

						<?php
						}// End if().
					}// End if().
					$count++;
				}// End while().
				wp_reset_query(); ?>
				</div>
				<?php
		}// End if().

		echo trim($args['after_widget']);
	}

	/**
	 * Handles updating settings for the current Trending widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 */

	function update( $new_instance, $old_instance ) {
		global $wpdb;
		$instance = $old_instance;
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['post_tags'] = $new_instance['post_tags'];
		$instance['link'] = $new_instance['link'];

		return $instance;
	}

	/**
	 * Outputs the Trending widget settings form.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */

	function form( $instance ) {

		//widgetform in backend
		$instance = wp_parse_args( (array) $instance, array(
			'title' => '',
			'category' => '',
			'number' => '',
		) );
		$title = strip_tags( $instance['title'] );
		$category = $instance['category'];
		$number = strip_tags( $instance['number'] );
		$post_tags = strip_tags( $instance['post_tags'] );
		$view = ( isset( $instance['view'] ) ) ? strip_tags( $instance['view'] ) : '';
		$link = strip_tags( $instance['link'] );
		$post_type = 'post';

		?>
		<p>
			<label for="<?php echo trim($this->get_field_id( 'title' )); ?>"><?php _e( 'Title:','livemagazine' ); ?></label>
			<input class="widefat" id="<?php echo trim($this->get_field_id( 'title' )); ?>" name="<?php echo trim($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo trim($title); ?>" />
		</p>

		<p>
			<label for="<?php echo trim($this->get_field_id( 'post_tags' )); ?>"><?php _e( 'Define Tags Slugs','livemagazine' ); ?>: </label>
			<input class="widefat" id="<?php echo trim($this->get_field_id( 'post_tags' )); ?>" name="<?php echo trim($this->get_field_name( 'post_tags' )); ?>" type="text" value="<?php echo trim($post_tags); ?>" />
			<small><?php echo __( 'Add tags slugs using comma(,)','livemagazine' ); ?></small>
		</p>

		<p>
			<label for="<?php echo trim($this->get_field_id( 'link' )); ?>"><?php echo __( 'View All Link URL: (ex.//templatic.com/events)', 'livemagazine' ); ?>
				<input class="widefat" id="<?php echo trim($this->get_field_id( 'link' )); ?>" name="<?php echo trim($this->get_field_name( 'link' )); ?>" type="text" value="<?php echo esc_attr( $link ); ?>" />
			</label>
		</p>

		<!--<p>
			<label for="<?php echo trim($this->get_field_id( 'number' )); ?>"><?php _e( 'Number of posts to show','livemagazine' ); ?>: </label>
			<input id="<?php echo trim($this->get_field_id( 'number' )); ?>" name="<?php echo trim($this->get_field_name( 'number' )); ?>" type="text" value="<?php echo trim($number); ?>" size="3" />
		</p>-->

		<?php
	}
}
/* EOF */
?>
