<?php
/**
 * Popular post widget class
 *
 */
class Tmpl_Widget_Popular_Posts extends WP_Widget {

	/**
	 * Sets up a new Popular Posts widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 */

	function __construct() {
		$widget_ops = array(
			'classname' => 'widget_popular_posts',
			'description' => __( 'Your site&#8217;s most popular Posts.','livemagazine' ),
		);
		parent::__construct( 'Tmpl_Widget_Popular_Posts', __( 'T &rarr; Popular Posts','livemagazine' ), $widget_ops );
		$this->alt_option_name = 'widget_per_cat_popular_posts';
	}


	/**
	 * Outputs the content for the current Popular Posts widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 */
	function widget( $args, $instance ) {
		ob_start();
		extract( $args );
		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'Popular Posts','livemagazine' );
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 8;

		$show_excerpt = isset( $instance['show_excerpt'] ) ? $instance['show_excerpt'] : false;

		/* popular posts query */
		$populer_post_args = new WP_Query( array(
			'post_type' => 'post',
			'orderby' => 'comment_count',
			'order' => 'DESC',
			'posts_per_page' => $number,
			'post_status' => 'publish',
		) );

		/* Loop start */
		global $post;
		if ( $populer_post_args->have_posts() ) :

			echo trim($args['before_widget']);
			if ( $title ) { echo trim($args['before_title']) . esc_html( $title ) . $args['after_title'];
			} ?>
				<div class="row">
				<?php
				while ( $populer_post_args->have_posts() ) : $populer_post_args->the_post(); ?>
					
						<div class="col-sm-6 col-xs-6 popular-post">
							<div class="item-image">
								<a href="<?php echo trim(get_permalink());?>">
								<?php
								if ( has_post_thumbnail() ) {
									the_post_thumbnail( 'tmpl-posts-thumb' );
								} else {
									echo '<img src="' . esc_url( get_stylesheet_directory_uri() ) . '/images/noimage-300x200.png" />';
								}
								?>
								</a>
							</div>
							<h4 class="item-title"><a href="<?php echo trim(get_permalink());?>"><?php the_title(); ?></a></h4>
						</div>
					
				<?php endwhile; ?>
				</div>
		<?php echo trim($args['after_widget']);

		/* Reset the global $the_post as this query will have stomped on it */
		wp_reset_postdata();
		else :
			echo '<p>';
			_e( 'No Popular Posts.','livemagazine' );
			echo '</p>';
		endif;
		/* Loop End */
	}

	/**
	 * Handles updating settings for the current Popular Post widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 */

	function update( $new_instance, $old_instance ) {
		return $new_instance;
	}

	/**
	 * Outputs the settings form for the Popular Post widget.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */

	function form( $instance ) {
		$title = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		$show_excerpt = isset( $instance['show_excerpt'] ) ? (bool) $instance['show_excerpt'] : false;
		?>
		<p>
			<label for="<?php echo trim($this->get_field_id( 'title' )); ?>"><?php _e( 'Title','livemagazine' ); ?>:</label>
			<input class="widefat" id="<?php echo trim($this->get_field_id( 'title' )); ?>" name="<?php echo trim($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo trim($title); ?>" />
		</p>

		<p>
			<label for="<?php echo trim($this->get_field_id( 'number' )); ?>"><?php _e( 'Number of posts to show','livemagazine' ); ?>:</label>
			<input id="<?php echo trim($this->get_field_id( 'number' )); ?>" name="<?php echo trim($this->get_field_name( 'number' )); ?>" type="text" value="<?php echo trim($number); ?>" size="3" />
		</p>

		<p>
			<input class="checkbox" type="checkbox" <?php checked( $show_excerpt ); ?> id="<?php echo trim($this->get_field_id( 'show_excerpt' )); ?>" name="<?php echo trim($this->get_field_name( 'show_excerpt' )); ?>" />
			<label for="<?php echo trim($this->get_field_id( 'show_excerpt' )); ?>"><?php _e( 'Display post excerpt?','livemagazine' ); ?></label>
		</p>

	<?php
	}
}
/* EOF */
?>
