<?php
/*
 *
 * Custom functions for the theme
 *
*/
global $wp_filesystem;
/* set global variable for theme settings */
add_action( 'wp_head','tmpl_magazine_theme_global_settings' );
function tmpl_magazine_theme_global_settings() {
	global $tmpl_magazine_theme_settings;

	$tmpl_magazine_theme_settings = get_option( 'templatic_theme_settings' );
	return $tmpl_magazine_theme_settings;
}

add_filter( 'comment_form_defaults', 'tmpl_magazine_comment_form_args' );
/**
 * Filters the WordPress comment_form() function that was added in WordPress 3.0.  This allows
 * the theme to preserve some backwards compatibility with its old comment form.  It also allows
 * users to build custom comment forms by filtering 'comment_form_defaults' in their child theme.
 */
if ( ! function_exists( 'tmpl_magazine_comment_form_args' ) ) {

	function tmpl_magazine_comment_form_args( $args ) {

		global $user_identity;
		/* Get the current commenter. */
		$commenter = wp_get_current_commenter();
		/* Create the required <span> and <input> element class. */
		$req = ( ( get_option( 'require_name_email' ) ) ? ' <span class="red">' . __( '*', 'livemagazine' ) . '</span> ' : '' );
		$input_class = ( ( get_option( 'require_name_email' ) ) ? ' req' : '' );
		/* Sets up the default comment form fields. */
		$fields = array(

			'author' => '<div class="inline-form-wrap"><div class="form-author form-group' . esc_attr( $input_class ) . '"><label for="author">' . __( 'Name', 'livemagazine' ) . $req . '</label> <input type="text" class="text-input" name="author" id="author" value="' . esc_attr( $commenter['comment_author'] ) . '" /></div>',
			'email' => '<div class="form-author form-group' . esc_attr( $input_class ) . '"><label for="email">' . __( 'Email', 'livemagazine' ) . $req . '</label> <input type="text" class="text-input" name="email" id="email" value="' . esc_attr( $commenter['comment_author_email'] ) . '" /></div>',
			'url' => '<div class="form-author form-group"><label for="url">' . __( 'Website', 'livemagazine' ) . '</label><input type="text" class="text-input" name="url" id="url" value="' . esc_attr( $commenter['comment_author_url'] ) . '" /></div></div>',
		);

		/* Sets the default arguments for displaying the comment form. */
		$login_page = get_option( 'tevolution_login' );
		if ( isset( $login_page ) ) {
			$login_url = get_permalink( $login_page );
		} else {
			$login_url  = wp_login_url( get_permalink() );
		}

		$args = array(
			'fields' => apply_filters( 'comment_form_default_fields', $fields ),
			'comment_field' => '<div class="form-textarea form-group req"><label for="comment">' . __( 'Message', 'livemagazine' ) . $req . '</label><textarea placeholfer="' . __( 'Your Comment here...','livemagazine' ) . '" name="comment" class="form-control" id="comment" cols="60" rows="5"></textarea></div>',
			'must_log_in' => '<p class="alert">' . __( 'You must be','livemagazine' ) . ' <a href="' . $login_url . '" title="' . __( 'Log in','livemagazine' ) . '">' . __( 'logged in','livemagazine' ) . '</a>' . __( ' to post a comment.', 'livemagazine' ) . '</p><!-- .alert -->',
			'logged_in_as' => '<p class="log-in-out">' . __( 'Logged in as', 'livemagazine' ) . ' ' . '<a href="' . get_author_posts_url( get_current_user_id() ) . '" title="' . esc_attr( $user_identity ) . '">' . esc_attr( $user_identity ) . '</a>. <a href="' . wp_logout_url( get_permalink() ) . '" title="' . __( 'Log out of this account', 'livemagazine' ) . '">' . __( 'Log out &raquo;', 'livemagazine' ) . '</a></p><!-- .log-in-out -->',
			'comment_notes_before' => '',
			'comment_notes_after' => '',
			'id_form' => 'commentform',
			'id_submit' => 'submit',
			'title_reply' => (get_post_type() == 'post')? __( 'Leave a Comment', 'livemagazine' ):__( 'Add a Review', 'livemagazine' ),
			'title_reply_to' => (get_post_type() == 'post')?__( 'Leave a Reply to %s', 'livemagazine' ) :__( 'Add a Review to %s', 'livemagazine' ),
			'cancel_reply_link' => __( 'Click here to cancel reply.', 'livemagazine' ),
			'label_submit' => __( 'Post Comment', 'livemagazine' ),
			'submit_button' => '<input type="submit" value="%4$s" class="%3$s btn btn-primary" id="%2$s" name="%1$s">',
			'submit_field' => '%1$s %2$s',
			'class_form' => 'commentform-wrap',
		);
		/* Return the arguments for displaying the comment form. */

		return $args;
	}
}// End if().


/*
 * Display the next and previous  pagination in single post page
 */

if ( ! function_exists( 'the_magazine_post_navigation' ) ) {
	function the_magazine_post_navigation() {
		global $post; ?>
			<div class="pos_navigation clearfix">
				<div class="post_left">
					<?php previous_post_link( '%link','<i class="fa angle-left"><svg version="1.1" xmlns="//www.w3.org/2000/svg" xmlns:xlink="//www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 197.402 197.402" xml:space="preserve"> <g><g><g><polygon points="146.883,197.402 45.255,98.698 146.883,0 152.148,5.418 56.109,98.698 152.148,191.98 "/></g></g></g></svg></i>  <span class="article-name">%title</span><span class="hidden visible-xs visible-sm">' . __( 'Prev','livemagazine' ) . '</span>' ) ?>
				</div>

				<div class="post_right">
					<?php next_post_link( '%link','<span class="article-name">%title</span><span class="hidden visible-xs visible-sm">' . __( 'Next','livemagazine' ) . '</span><i class="fa angle-right fa-flip-horizontal"><svg version="1.1" xmlns="//www.w3.org/2000/svg" xmlns:xlink="//www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 197.402 197.402" xml:space="preserve"> <g><g><g><polygon points="146.883,197.402 45.255,98.698 146.883,0 152.148,5.418 56.109,98.698 152.148,191.98 "/></g></g></g></svg></i>' ) ?>
				</div>
			</div>
		<?php
	}
}


add_action( 'admin_menu', 'tmpl_magazine_theme_settings',9999 );
/*
	To create submenu for theme settings in Appearance menu
*/
if ( ! function_exists( 'tmpl_magazine_theme_settings' ) ) {
	function tmpl_magazine_theme_settings() {
		add_theme_page( __( 'Custom CSS Editor','livemagazine' ),__( 'Custom CSS Editor','livemagazine' ),'manage_options','templatic_custom_css_editor','tmpl_magazine_custom_css_editor_settings' );
		add_theme_page( __( 'Theme Settings','livemagazine' ), __( 'Theme Settings','livemagazine' ), 'manage_options', 'theme-settings-page', 'tmpl_magazine_settings_page_callback' );
	}
}

/*
	save custom css in an option table
*/
if ( ! function_exists( 'tmpl_magazine_custom_css_editor_settings' ) ) {

	function tmpl_magazine_custom_css_editor_settings() {
		$title = __( 'Custom CSS Editor','livemagazine' );
		$file = get_template_directory() . '/custom.css';?>


		<?php
		$theme = 'LiveMagazine';
		if ( $theme ) {
			$stylesheet = $theme;
		} else { $stylesheet = get_stylesheet();
		}

		$theme = wp_get_theme( $stylesheet );
		$allowed_files = $theme->get_files( 'php', 1 );
		$has_templates = ! empty( $allowed_files );
		$style_files = $theme->get_files( 'css' );
		$allowed_files['style.css'] = $style_files['style.css'];
		$allowed_files += $style_files;

		$relative_file = 'custom.css';
		/* if action set to updates write custom.css file then redirect on currect place */
		if ( isset( $_POST['action'] ) && $_POST['action'] == 'update' ) {

			check_admin_referer( 'edit-theme_' . $file . $stylesheet );
			$newcontent = wp_unslash( $_POST['custom_css_content'] );
			update_option( 'LiveMagazine_custom_css',$newcontent );
			$location = 'themes.php?page=templatic_custom_css_editor';
			$location .= '&updated=true';
			wp_redirect( $location );
			exit;
		}
		$content = '';

		if ( file_exists( $file ) ) {
			if ( (!isset($error) || !$error) && filesize( $file ) > 0 ) {

				global $wp_filesystem;
				$content = $wp_filesystem->get_contents($file);

				if ( '.php' == substr( $file, strrpos( $file, '.' ) ) ) {
					$functions = wp_doc_link_parse( $content );

					$docs_select = '<select name="docs-list" id="docs-list">';
					$docs_select .= '<option value="">' . esc_attr__( 'Function Name&hellip;','livemagazine' ) . '</option>';
					foreach ( $functions as $function ) {
						$docs_select .= '<option value="' . esc_attr( urlencode( $function ) ) . '">' . htmlspecialchars( $function ) . '()</option>';
					}
					$docs_select .= '</select>';
				}

				$content = esc_textarea( $content );
			}
		}
		?>
		<div class="wrap">
		<h2><?php echo esc_html( $title ); ?></h2>
		 <p> <?php echo sprintf( __( 'You can customize the theme by entering CSS classes in this section. Enter only the classes you want to overwrite (not the whole style.css file). For details on using custom.css open %s.','livemagazine' ),'<a href="//templatic.com/docs/using-custom-css-for-theme-customizations/">this article</a>' );?></p>

		<?php if ( isset( $_GET['updated'] ) && $_GET['updated'] == 'true' ) { ?>
			<div class="updated" id="message"><p><?php echo __( 'File edited successfully.','livemagazine' ); ?></p></div>
		<?php } ?>
		<form name="custom_css" id="template" action="" method="post">
		<?php wp_nonce_field( 'edit-theme_' . $file . $stylesheet ); ?>
			<div><textarea cols="70" rows="30" name="custom_css_content" id="custom_css_content" aria-describedby="newcontent-description"><?php echo  esc_html($content); ?></textarea>
			<input type="hidden" name="action" value="update" />
			<input type="hidden" name="file" value="<?php echo esc_attr( $relative_file ); ?>" />
			<input type="hidden" name="theme" value="<?php echo esc_attr( $theme->get_stylesheet() ); ?>" />
			<input type="hidden" name="scrollto" id="scrollto" value="0" />
			<?php
			if ( get_option( 'directory_custom_css' ) ) {
				if ( is_writeable( $file ) ) :
					submit_button( __( 'Update File','livemagazine' ), 'primary', 'submit', true );
				else : ?>
			<p><em><?php __( 'You need to make this file writable before you can save your changes. See <a href="//codex.wordpress.org/Changing_File_Permissions">the Codex</a> for more information in directory root folder.','livemagazine' ); ?></em></p>
			<?php endif;
			} else {
				submit_button( __( 'Update File', 'livemagazine' ), 'primary', 'submit', true );
			}?>
			</div>
		</form>
		</div>
	<?php
	}
}// End if().

/*
	To display theme setting options in appearance -> theme settings
*/
if ( ! function_exists( 'tmpl_magazine_settings_page_callback' ) ) {

	function tmpl_magazine_settings_page_callback() {
		if ( function_exists( 'supreme_prefix' ) ) {
			$pref = supreme_prefix();
		} else {
			$pref = sanitize_key( apply_filters( 'hybrid_prefix', get_template() ) );
		}
		$theme_settings = get_option( $pref . '_theme_settings' ); ?>
		<div class="wrap">
			<form name="theme_options_settings" id="theme_options_settings" method="post" enctype="multipart/form-data">
				<?php

				/* save general setting
				*
                * parameter : "tmpl_magazine_is_rtl" for if RTL mode is enabled or not
				*
				*/
				if ( isset( $_REQUEST['Submit'] ) && ! empty( $_REQUEST['Submit'] ) ) {

					$tmpl_magazine_is_rtl = (isset( $_REQUEST['tmpl_magazine_is_rtl'] ) && ! empty( $_REQUEST['tmpl_magazine_is_rtl'] )) ? $_REQUEST['tmpl_magazine_is_rtl'] : 0;
					update_option( 'tmpl_magazine_is_rtl',$tmpl_magazine_is_rtl );

					$tmpl_magazine_excerpt_length = (isset( $_REQUEST['tmpl_magazine_excerpt_length'] ) && ! empty( $_REQUEST['tmpl_magazine_excerpt_length'] )) ? $_REQUEST['tmpl_magazine_excerpt_length'] : 55;
					update_option( 'tmpl_magazine_excerpt_length',$tmpl_magazine_excerpt_length );

				} ?>

				<input type="hidden" name="theme_options_nonce" value="<?php echo esc_attr( wp_create_nonce( basename( __FILE__ ) ) ); ?>" />
				<div class="icon32 icon32-posts-post" id="icon-edit"><br></div>
				<h2>
					<?php echo __( 'Theme Settings','livemagazine' );?>
				</h2>

				<?php if ( isset( $_REQUEST['updated'] ) && $_REQUEST['updated'] != '' ) {?>
				<div class="updated" id="message" style="clear:both">
					<p>
						<?php echo __( 'Theme Settings','livemagazine' );?>
						<strong><?php echo __( 'saved','livemagazine' );?></strong>
					</p>
				</div>
				<?php }?>

				<div class="wp-filter tev-sub-menu" >
					<ul id="tev_theme_settings" class="filter-links">
						<li class="general_settings active"><a id="general_settings" href="javascript:void(0);" class="current">
							<?php echo __( 'General Settings','livemagazine' );?>
						</a> </li>

					</ul>
				</div>
				<table id="general_settings" class="tmpl-theme_settings form-table active-tab">
					<tbody>
						<!-- General Settings -->
						<tr>
							<th>
								<label for="supreme_show_breadcrumb">
									<?php echo __( 'Enable RTL','livemagazine' );?>
								</label>
							</th>
							<td>
								<div class="input-switch">
									<input type="checkbox" value="1"  <?php echo (@get_option( 'tmpl_magazine_is_rtl' ) == 1) ? 'checked' : ''?> id="tmpl_magazine_is_rtl" name="tmpl_magazine_is_rtl">
									<label for="tmpl_magazine_is_rtl">
										<?php echo __( 'Enable','livemagazine' );?>
									</label>
								</div>
								<p class="description">
									<?php echo __( 'Enabling this option will activate the rtl.css file. This is a must for languages like Hebrew or Arabic.','livemagazine' );?>
								</p>
							</td>
						</tr>

						<tr>
							<th>
								<label for="supreme_show_breadcrumb">
									<?php echo __( 'Excerpt Length','livemagazine' );?>
								</label>
							</th>
							<td>
								<div class="input-switch">
									<input type="text" value="<?php echo @get_option( 'tmpl_magazine_excerpt_length' ); ?>" id="tmpl_magazine_excerpt_length" name="tmpl_magazine_excerpt_length">
								</div>
								<p class="description">
									<?php echo __( 'Add the number adjusting to match the number of words you wish to display in the excerpt. By default the excerpt length is set to return 55 words','livemagazine' );?>
								</p>
							</td>
						</tr>

						<tr>
							<td colspan="2">
								<p style="clear: both;" class="submit">
									<input type="submit" value="<?php echo __( 'Save All Settings','livemagazine' ); ?>" class="button button-primary button-hero" name="Submit">
								</p>
							</td>
						</tr>
					</tbody>
				</table>

			</form>
		</div>
<?php
	}
}// End if().


/* css for switch for checkbox in theme settings */
add_action( 'admin_head', 'tmpl_magazine_admin_css' );
if ( ! function_exists( 'tmpl_magazine_admin_css' ) ) {

	function tmpl_magazine_admin_css() {
	?>
		<style>
			.input-switch { position: relative; }
			.input-switch input[type='checkbox'] {vertical-align: top; left: 0; opacity: 0; position: relative; width: 18px; margin: 0!important; padding: 0!important; }
			.templatic_settings table.form-table tr td .input-switch input[type='checkbox'] + label, .input-switch input[type='checkbox'] + label { line-height: 20px; font-size: 0; margin: 0 0 0 -20px !important; clear: none; position: relative; padding: 0; cursor: pointer; display: inline-block; }
			.input-switch input[type='checkbox'] + label:before { border: 1px solid #bbb; border-radius: 3px; height: 24px; width: 70px; content: ""; display: inline-block; background-color: #f7f7f7; box-shadow: 0 1px 0 #fff inset, 0 1px 0 rgba(0, 0, 0, 0.08); -webkit-box-shadow:0 1px 0 #fff inset, 0 1px 0 rgba(0, 0, 0, 0.08);}
			.input-switch input[type='checkbox'] + label:after { content: "off"; font-size: 14px; padding-left: 13px; position: absolute; left: 3px; right: auto; top: 3px; color: #999; border-left: 25px solid #434343;}
			.input-switch input[type='checkbox']:checked + label:after { content: "on"; left:auto; right: 3px; padding-left: 0; padding-right: 13px; border-left: 0; border-right: 25px solid #2ea2cc; color: #434343; }
		</style>
	<?php
	}
}


/* get category checklist tree EOF*/
/************************************
//FUNCTION NAME : commentslist
//ARGUMENTS :comment data, arguments,depth level for comments reply
//RETURNS : Comment listing format
***************************************/
function tmpl_magazine_commentslist( $comment, $args, $depth ) {

	global $rating_table_name,$wpdb,$rating_path;
	$GLOBALS['comment'] = $comment;
?>

	<li>
		<div id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
		<div class="comment_left">
			<?php echo get_avatar( $comment, 64 ); ?>

				  <span class="comment_arrow"></span>
		</div>
			<div class="comment-text">
				<div class="comment-text-inner-wrapper">
					<div class="comment-star-container">
						<?php

						printf( '<p class="comment-author"><span>%s</span></p>', get_comment_author_link() );

						/* comments meta */
						printf( '<p class="comment-date">%s</p>', get_comment_date() );
						?>
					</div>
					<p class="comment-reply-link-wrapper"><?php comment_reply_link( array_merge( $args, array(
						'depth' => $depth,
						'max_depth' => $args['max_depth'],
					) ) ) ?></p>
				</div>
				<?php if ( $comment->comment_approved == '0' ) : ?>
					<p class="comment-waiting"><?php _e( 'Your comment is awaiting moderation.','livemagazine' ) ?></p>

									<?php endif;
					comment_text();
					?>
			</div>
		 </div>
<?php

}

/* show breadcrumb for pages */
add_action( 'tmpl_magazine_breadcrumb','tmpl_magazine_breadcrumb_callback' );
function tmpl_magazine_breadcrumb_callback() {
	tmpl_magazine_breadcrumb_trail();
}

/* function for adding meta tags for facebook */
add_action( 'wp_head','tmpl_magazine_fb_metatags' );
function tmpl_magazine_fb_metatags() {

	if ( is_single() ) {
		global $post;

		/* if post has thumbnai then add meta tag for image */
		if ( has_post_thumbnail() ) {
			$large_image_url = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ),'full' );
			?>
			<meta property="og:image" content="<?php echo  esc_html($large_image_url[0]) ?>" />
			<?php

		}
		?>
		<meta property="og:title" content="<?php echo  esc_html($post->post_title); ?>" />
		<meta property="og:url" content="<?php echo get_permalink( $post->ID ); ?>" />
		<meta property="og:description" content="<?php if ( $post->post_excerpt ) { echo strip_tags( $post->post_excerpt );
} else { echo strip_tags( $post->post_content ); } ?>" />
		<meta property="fb:app_id" content="966242223397117 " />

		<?php
	}
}

/* show social sharing buttons on post page */
add_action( 'tmpl_magazine_after_content','tmpl_magazine_social_sharing_buttons' );
if ( ! function_exists( 'tmpl_magazine_social_sharing_buttons' ) ) {
	function tmpl_magazine_social_sharing_buttons() {
	?>

		<div class="social-media-shareicon">
			<ul>
				<li>
					<a class="twitter" href="//twitter.com/home?status=Reading: <?php the_permalink(); ?>" title="<?php _e( 'Share this post on Twitter!','livemagazine' ); ?>" target="_blank">
						<i class="step fa fa-twitter"></i><span class="social-button-count"><?php _e( 'Twitter','livemagazine' ); ?></span>
					</a>
				</li>

				<li>
					<a class="facebook" href="//www.facebook.com/sharer.php?u=<?php the_permalink();?>&amp;t=<?php the_title(); ?>" title="<?php _e( 'Share this post on Facebook!','livemagazine' ); ?>" target="_blank">
						<i class="step fa fa-facebook"></i><span class="social-button-count"><?php _e( 'Facebook','livemagazine' ); ?></span>
					</a>
				</li>

				<!--<li>
					<a class="googleplus" target="_blank" href="https://plus.google.com/share?url=<?php //the_permalink(); ?>">
						<i class="fa fa-google-plus"></i><span class="social-button-count"><?php //_e( 'Google+','livemagazine' ); ?></span>
					</a>
				</li>-->

				<li>
					<a class="pinterest" href="//pinterest.com/pin/create/button/?url=<?php the_permalink(); ?>"  count-layout="none">
						<i class="fa fa-pinterest"></i> <span class="social-button-count"><?php _e( 'Pin It','livemagazine' ); ?></span>
					</a>
				</li>

				<li>
					<a class="linkedin" target="_blank" href="//www.linkedin.com/shareArticle?mini=true&url=<?php the_permalink(); ?>&title=<?php the_title(); ?>&summary=<?php the_title(); ?>&source=<?php echo home_url(); ?>"  count-layout="none">
						<i class="fa fa-linkedin"></i><span class="social-button-count"> <?php _e( 'LinkedIn','livemagazine' );?></span>
					</a>
				</li>

			</ul>
		</div>

		<?php
	}
}// End if().

/*
 * set the excerpt length as per value set in theme settings.
 * By default it will be 55 words
 * @parameters: $length - number of words
 *
 */
add_filter( 'excerpt_length', 'tmpl_magazine_excerpt_length', 999 );
if ( ! function_exists( 'tmpl_magazine_excerpt_length' ) ) {

	function tmpl_magazine_excerpt_length( $length ) {
		$excerpt_lenght = get_option( 'tmpl_magazine_excerpt_length' );
		if ( $excerpt_lenght != '' ) {
			$length = get_option( 'tmpl_magazine_excerpt_length' );
		}
		return $length;
	}
}

/* excerpt more link */
add_filter( 'excerpt_more', 'tmpl_magazine_read_more_link' );
if ( ! function_exists( 'tmpl_magazine_read_more_link' ) ) {

	function tmpl_magazine_read_more_link() {
		return '<a title="' . __( 'Read More..','livemagazine' ) . '" class="more-link" href="' . get_permalink() . '"> ' . __( 'Continue Reading','livemagazine' ) . ' &rarr; </a>';
	}
}

/* category, archive, tags navigation  */
add_filter( 'navigation_markup_template', 'tmpl_magazine_navigation_markup_template',10,2 );
if ( ! function_exists( 'tmpl_magazine_navigation_markup_template' ) ) {
	function tmpl_magazine_navigation_markup_template( $template, $class ) {

		$template = '
			<div class="pos_navigation clearfix">
				%3$s
			</div>';

		return $template;

	}
}
/* EOF */

/* display post metas in all pages */

function tmpl_display_post_meta_boxes( $post ) {
	global $post;
	/* get author info */
	$author = get_the_author();
	if ( $author ) {
		$user_url = get_the_author_meta( 'user_url' );
		if ( $user_url ) {
			echo '<a class="auther" href="' . $user_url . '">' . $author . '</a> <span class="text-sep">/</span>';
		} else {
			$user_details = get_userdata( $post->post_author );
			$user_url = site_url() . '/author/' . $user_details->user_login;
			echo '<a class="auther" href="' . $user_url . '"> ' . $author . '</a> <span class="text-sep">/</span>';
		}
	}

	/* get publish date */
	$publish_date = get_the_date();
	if ( $publish_date ) {
		echo '<span class="date">' . $publish_date . '</span> ';
	}

}

/* pagination on archive pages */
if ( ! function_exists( 'wp_pagenavi' ) ) {
	function wp_pagenavi( $before = '', $after = '', $prelabel = '', $nxtlabel = '', $pages_to_show = 5, $always_show = false ) {

		global $request, $posts_per_page, $wpdb, $paged;
		if ( empty( $prelabel ) ) {
			$prelabel  = '<strong>&laquo;</strong>';
		}
		if ( empty( $nxtlabel ) ) {
			$nxtlabel = '<strong>&raquo;</strong>';
		}
		$half_pages_to_show = round( $pages_to_show / 2 );
		if ( ! is_single() ) {
			if ( is_tag() ) {
				preg_match( '#FROM\s(.*)\sGROUP BY#siU', $request, $matches );
			} elseif ( is_category() ) {
				preg_match( '#FROM\s(.*)\sORDER BY#siU', $request, $matches );
			} else {
				preg_match( '#FROM\s(.*)\sGROUP BY#siU', $request, $matches );
			}
			/* If its concate group by then on category page pagination will not work */
			if(is_author()){
				$numpostsAlt = $GLOBALS['wp_query']->found_posts; //alternative post count

				if(isset($matches[1]))
				$fromwhere = str_replace( "GROUP BY $wpdb->posts.ID",'',$matches[1] );
				if(isset($fromwhere))
				$numposts = $wpdb->get_var( "SELECT COUNT(DISTINCT ID) FROM $fromwhere" );
				if(isset($numposts))
					$max_page = ceil( $numposts / $posts_per_page );
				else
					$max_page = ceil( $numpostsAlt / $posts_per_page ); // if $numposts is not isset
			}else{
				$fromwhere = str_replace( "GROUP BY $wpdb->posts.ID",'',$matches[1] );
				$numposts = $wpdb->get_var( "SELECT COUNT(DISTINCT ID) FROM $fromwhere" );
				$max_page = ceil( $numposts / $posts_per_page );
			}

			if ( empty( $paged ) ) {
				$paged = 1;
			}
			if ( $max_page > 1 || $always_show ) {
				echo "$before <div class='Navi'>";
				if ( $paged >= ($pages_to_show -1) ) {
					echo '<a href="' . str_replace( '&paged','&amp;paged',get_pagenum_link() ) . '">&laquo;</a>';
				}
				previous_posts_link( $prelabel );
				for ( $i = $paged - $half_pages_to_show; $i <= $paged + $half_pages_to_show; $i++ ) {
					if ( $i >= 1 && $i <= $max_page ) {
						if ( $i == $paged ) {
							echo "<strong class='on'>$i</strong>";
						} else {
							echo ' <a href="' . str_replace( '&paged','&amp;paged',get_pagenum_link( $i ) ) . '">' . $i . '</a> ';
						}
					}
				}
				next_posts_link( $nxtlabel, $max_page );
				if ( ($paged + $half_pages_to_show) < ($max_page) ) {
					echo '<a href="' . str_replace( '&paged','&amp;paged',get_pagenum_link( $max_page ) ) . '">&raquo;</a>';
				}
				echo "</div> $after";
			}
		}// End if().
	}
}// End if().

/* register megamenu widget ares - its regster through the global variable we pAss from plugins */
add_action( 'widgets_init', 'tmpl_register_sidebars' );
function tmpl_register_sidebars() {

	if ( defined('MEGAMENU_VERSION')) {
		register_sidebar( array(
			'name' => __( 'Mega Menu Navigation', 'livemagazine' ),
			'id' => 'mega_menu',
			'description' => __( 'Load only jquery mega menu in Secondary Navigation menu.', 'livemagazine' ),
			'before_widget' => '<li id="%1$s" class="widget %2$s">',
			'after_widget'  => '</li>',
			'before_title'  => '<h2 class="widgettitle">',
			'after_title'   => '</h2>',
		) );
	}

}
/*
	Save custom css in a file from option
*/
add_action( 'init','save_custom_css' );
function save_custom_css() {
	global $wp_filesystem;
	/* DOING_AJAX is define then return false for admin ajax*/
	if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {
		return ;
	}

	$file = get_template_directory() . '/custom.css';
	$theme = 'LiveMagazine';
	if ( $theme ) {
		$stylesheet = $theme;
	} else { $stylesheet = get_stylesheet();
	}

	$theme = wp_get_theme( $stylesheet );

	{
	if ( ! file_exists( $file ) ) {
		//fopen( $file, 'w+' );
		$wp_filesystem->put_contents($file, '', 666);

	}
	}
	$newcontent = get_option( 'LiveMagazine_custom_css' );
	if ( is_writeable( $file ) ) {
		//is_writable() not always reliable, check return value. see comments @ //uk.php.net/is_writable
		/*$f = fopen( $file, 'w+' );
		if ( $f !== false ) {
			fwrite( $f, $newcontent );
			fclose( $f );
			$theme->cache_delete();
		}*/
		$wp_filesystem->put_contents($file, $newcontent, 666);
		$theme->cache_delete();
	}
}

function tmpl_magazine_remove_hentry( $classes ) {
	if ( is_page() ) {
		$classes = array_diff( $classes, array( 'hentry' ) );
	}
	return $classes;
}
add_filter( 'post_class','tmpl_magazine_remove_hentry' );

/* EOF */
?>
